@@ -9,9 +9,9 @@
 
 #include <QObject>
 
+#include <KIO/Job>
+#include <KMime/HeaderParsing>
 #include <QUrl>
-#include <kio/job.h>
-#include <kmime/kmime_header_parsing.h>
 
 class QDomElement;
 class QDomDocument;
@@ -46,7 +46,7 @@ public:
     explicit Ispdb(QObject *parent = nullptr);
 
     /** Destructor */
-    ~Ispdb();
+    ~Ispdb() override;
 
     /** After finished() has been emitted you can
         retrieve the domains that are covered by these
