@@ -18,7 +18,7 @@ class ServerTest : public QObject
     Q_OBJECT
 public:
     explicit ServerTest(QObject *parent);
-    ~ServerTest();
+    ~ServerTest() override;
 
 public Q_SLOTS:
     /* @p protocol being 'imap' 'smtp' or 'pop3' */
